-------------------------------------------------------------------------------
-- Addon namespace
-------------------------------------------------------------------------------
local nanoPar = CreateFrame("Frame", nil, UIParent)
nanoPar:SetScript("OnEvent", function(self, event, ...)	if self[event] then return self[event](self, event, ...) end end)

local LDB = LibStub:GetLibrary("LibDataBroker-1.1")

local DataObj = LDB:NewDataObject("nanoPar", {
	type	= "data source",
	label	= "nanoPar",
	text	= "0",
	icon	= "Interface\\Icons\\INV_Shield_36",
})

-------------------------------------------------------------------------------
-- Helper functions
-------------------------------------------------------------------------------
local function GetTipAnchor(frame)
	local x,y = frame:GetCenter()

	if not x or not y then return "TOPLEFT", "BOTTOMLEFT" end

	local hhalf = (x > UIParent:GetWidth()*2/3) and "RIGHT" or (x < UIParent:GetWidth()/3) and "LEFT" or ""
	local vhalf = (y > UIParent:GetHeight()/2) and "TOP" or "BOTTOM"
	return vhalf..hhalf, frame, (vhalf == "TOP" and "BOTTOM" or "TOP")..hhalf
end

local function myIOPscore()
	local _, iscore, _, pscore = IOP_GetItemLevels("player")
	local retval = iscore
	if (IOP.Options.pvpValues == 1) then retval = pscore end
	return format("%.2f", retval)
end

-------------------------------------------------------------------------------
-- Event Handlers
-------------------------------------------------------------------------------
function nanoPar:UNIT_INVENTORY_CHANGED() DataObj.text = myIOPscore() end

function nanoPar:PLAYER_LOGIN()
	LibStub("tekKonfig-AboutPanel").new(nil, "nanoPar")
	DataObj.text = myIOPscore()
	self:Show()
	self:RegisterEvent("UNIT_INVENTORY_CHANGED")
	self:UnregisterEvent("PLAYER_LOGIN")
	self.PLAYER_LOGIN = nil
end

-------------------------------------------------------------------------------
-- LDB Functions
-------------------------------------------------------------------------------
function DataObj.OnLeave() GameTooltip:Hide() end

function DataObj.OnEnter(self)
	GameTooltip:SetOwner(self, "ANCHOR_NONE")
	GameTooltip:SetPoint(GetTipAnchor(self))
	GameTooltip:ClearLines();

	GameTooltip:AddLine("nanoPar");
	GameTooltip:AddLine(IOP_GetItemLevels("player"))
	GameTooltip:AddLine(" ")
	GameTooltip:AddDoubleLine("Click to show recorded scores.", "Shift-Click for options.", nil, nil, nil, nil, nil, nil)
	GameTooltip:AddDoubleLine("Ctrl-Click for your details.", "Alt-Click for Target's details.", nil, nil, nil, nil, nil, nil)
	GameTooltip:Show()
end

function DataObj.OnClick() 
	if IsShiftKeyDown() then 
		ShowUIPanel(InventoryOnParOptionFrame)
	elseif IsControlKeyDown() then
		IOP_ShowPlayerDoll()
	elseif IsAltKeyDown() then
		local name = UnitName("target")
		if name and UnitIsPlayer("target") then
			IOP_UI_ShowTooltip(name)
		end
	else
		ShowUIPanel(InventoryOnParUIFrame)
	end
	PlaySound("GAMEGENERICBUTTONPRESS")
end

-------------------------------------------------------------------------------
-- Initialization
-------------------------------------------------------------------------------
if IsLoggedIn() then nanoPar:PLAYER_LOGIN() else nanoPar:RegisterEvent("PLAYER_LOGIN") end
